==> scilab_5.1.orig.tar.gz: scilab-5.1/modules/graphics/src/c/getHandleProperty/get_pixel_drawing_mode_property.c <==
/*
 * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
 * Copyright (C) 2004-2006 - INRIA - Fabrice Leray
 * Copyright (C) 2006 - INRIA - Allan Cornet
 * Copyright (C) 2006 - INRIA - Jean-Baptiste Silvy
 * 
 * This file must be used under the terms of the CeCILL.
 * This source file is licensed as described in the file COPYING, which
 * you should have received as part of this distribution.  The terms
 * are also available at    
 * http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
 *
 */

/*------------------------------------------------------------------------*/
/* file: get_pixel_drawing_mode_property.c                                */
/* desc : function to retrieve in Scilab the pixel_drawing_mode field of  */
/*        a handle                                                        */
/*------------------------------------------------------------------------*/
#include "localization.h"
#include "getHandleProperty.h"
#include "stack-c.h"
#include "GetProperty.h"
#include "pixel_mode.h"
#include "returnProperty.h"
#include "Scierror.h"
#include "localization.h"
/*------------------------------------------------------------------------*/

int get_pixel_drawing_mode_property( sciPointObj * pobj )
{
  if ( sciGetEntityType (pobj) == SCI_FIGURE )
  {
    return sciReturnString( getPixelMode( pFIGURE_FEATURE (pobj)->gmode.xormode ) ) ;
  }
  else
  {
    Scierror(999, _("%s property does not exist for this handle.\n"),"pixel_drawing_mode");
    return -1 ;
  }

}

/*------------------------------------------------------------------------*/

==> scilab_5.3.3.orig.tar.gz: scilab-5.3.3/modules/graphics/src/c/getHandleProperty/get_pixel_drawing_mode_property.c <==
/*
 * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
 * Copyright (C) 2004-2006 - INRIA - Fabrice Leray
 * Copyright (C) 2006 - INRIA - Allan Cornet
 * Copyright (C) 2006 - INRIA - Jean-Baptiste Silvy
 * 
 * This file must be used under the terms of the CeCILL.
 * This source file is licensed as described in the file COPYING, which
 * you should have received as part of this distribution.  The terms
 * are also available at    
 * http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
 *
 */

/*------------------------------------------------------------------------*/
/* file: get_pixel_drawing_mode_property.c                                */
/* desc : function to retrieve in Scilab the pixel_drawing_mode field of  */
/*        a handle                                                        */
/*------------------------------------------------------------------------*/

#include "getHandleProperty.h"
#include "GetProperty.h"
#include "pixel_mode.h"
#include "returnProperty.h"
#include "Scierror.h"
#include "localization.h"
/*------------------------------------------------------------------------*/

int get_pixel_drawing_mode_property( sciPointObj * pobj )
{
  if ( sciGetEntityType (pobj) == SCI_FIGURE )
  {
    return sciReturnString( getPixelMode( pFIGURE_FEATURE (pobj)->gmode.xormode ) ) ;
  }
  else
  {
    Scierror(999, _("'%s' property does not exist for this handle.\n"),"pixel_drawing_mode");
    return -1 ;
  }

}

/*------------------------------------------------------------------------*/
